svld1sb_vnum_u16

Function svld1sb_vnum_u16 

pub unsafe fn svld1sb_vnum_u16(
    pg: svbool_t,
    base: *const i8,
    vnum: i64,
) -> svuint16_t
🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)
Available on target feature sve and (AArch64 or ARM64EC) only.
Load 8-bit data and sign-extend Arm’s documentation

Safety

  • pointer::offset safety constraints must be met for the address calculation for each active element (governed by pg). In particular, note that vnum is scaled by the vector length, VL, which is not known at compile time.
  • This dereferences and accesses the calculated address for each active element (governed by pg).