svld1ub_vnum_u64

Function svld1ub_vnum_u64 

pub unsafe fn svld1ub_vnum_u64(
    pg: svbool_t,
    base: *const u8,
    vnum: i64,
) -> svuint64_t
🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)
Available on target feature sve and (AArch64 or ARM64EC) only.
Load 8-bit data and zero-extend Arm’s documentation

Safety

  • pointer::offset safety constraints must be met for the address calculation for each active element (governed by pg). In particular, note that vnum is scaled by the vector length, VL, which is not known at compile time.
  • This dereferences and accesses the calculated address for each active element (governed by pg).