pub unsafe fn svld4_vnum_s32(
pg: svbool_t,
base: *const i32,
vnum: i64,
) -> svint32x4_t🔬This is a nightly-only experimental API. (
stdarch_aarch64_sve #145052)Available on target feature
sve and (AArch64 or ARM64EC) only.Expand description
Load four-element tuples into four vectors Arm’s documentation
Safety
pointer::offsetsafety constraints must be met for the address calculation for each active element (governed bypg). In particular, note thatvnumis scaled by the vector length,VL, which is not known at compile time.- This dereferences and accesses the calculated address for each active element (governed by
pg).