svprfh_vnum

Function svprfh_vnum 

pub unsafe fn svprfh_vnum<const OP: svprfop, T>(
    pg: svbool_t,
    base: *const T,
    vnum: i64,
)
🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)
Available on target feature sve and (AArch64 or ARM64EC) only.
Prefetch halfwords Arm’s documentation

Safety

  • pointer::offset safety constraints must be met for the address calculation for each active element (governed by pg). In particular, note that vnum is scaled by the vector length, VL, which is not known at compile time.