pub unsafe fn svprfw_vnum<const OP: svprfop, T>(
pg: svbool_t,
base: *const T,
vnum: i64,
)🔬This is a nightly-only experimental API. (
stdarch_aarch64_sve #145052)Available on target feature
sve and (AArch64 or ARM64EC) only.Expand description
Prefetch words Arm’s documentation
Safety
pointer::offsetsafety constraints must be met for the address calculation for each active element (governed bypg). In particular, note thatvnumis scaled by the vector length,VL, which is not known at compile time.