svst4_vnum_s8

Function svst4_vnum_s8 

pub unsafe fn svst4_vnum_s8(
    pg: svbool_t,
    base: *mut i8,
    vnum: i64,
    data: svint8x4_t,
)
🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)
Available on target feature sve and (AArch64 or ARM64EC) only.
Store four vectors into four-element tuples Arm’s documentation

Safety

  • pointer::offset safety constraints must be met for the address calculation for each active element (governed by pg). In particular, note that vnum is scaled by the vector length, VL, which is not known at compile time.
  • This dereferences and accesses the calculated address for each active element (governed by pg).